==> ktechlab-trinity-14.0.13.tar.xz: ktechlab-trinity-14.0.13/src/circuitview.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by David Saxton                                    *
 *   david@bluehaze.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "circuitdocument.h"
#include "circuitview.h"
#include "ktechlab.h"
#include "simulator.h"
#include "viewiface.h"

#include <tdelocale.h>
#include <tqwhatsthis.h>

CircuitView::CircuitView( CircuitDocument * circuitDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name )
	: ICNView( circuitDocument, viewContainer, viewAreaId, name ),
	p_circuitDocument(circuitDocument)
{
	TDEActionCollection * ac = actionCollection();
	
	new TDEAction( "Dump linear equations", TQt::CTRL|TQt::Key_D, circuitDocument, TQT_SLOT(displayEquations()), ac, "dump_les" );
	
	//BEGIN Item Control Actions
	TDERadioAction * ra;
	ra = new TDERadioAction( i18n("0 Degrees"), "", 0, circuitDocument, TQT_SLOT(setOrientation0()), ac, "edit_orientation_0" );
	ra->setExclusiveGroup("orientation");
	ra->setChecked(true);
	ra = new TDERadioAction( i18n("90 Degrees"), "", 0, circuitDocument, TQT_SLOT(setOrientation90()), ac, "edit_orientation_90" );
	ra->setExclusiveGroup("orientation");
	ra = new TDERadioAction( i18n("180 Degrees"), "", 0, circuitDocument, TQT_SLOT(setOrientation180()), ac, "edit_orientation_180" );
	ra->setExclusiveGroup("orientation");
	ra =new TDERadioAction( i18n("270 Degrees"), "", 0, circuitDocument, TQT_SLOT(setOrientation270()), ac, "edit_orientation_270" );
	ra->setExclusiveGroup("orientation");
	
	new TDEAction( i18n("Create Subcircuit"), "", 0, circuitDocument, TQT_SLOT(createSubcircuit()), ac, "circuit_create_subcircuit" );
	new TDEAction( i18n("Rotate Clockwise"), "object-rotate-right", "]", circuitDocument, TQT_SLOT(rotateClockwise()), ac, "edit_rotate_cw" );
	new TDEAction( i18n("Rotate Counter-Clockwise"), "object-rotate-left", "[", circuitDocument, TQT_SLOT(rotateCounterClockwise()), ac, "edit_rotate_ccw" );
	new TDEAction( i18n("Flip"), "", 0, circuitDocument, TQT_SLOT(itemFlip()), ac, "edit_flip" );
	//END Item Control Actions
	
	setXMLFile( "ktechlabcircuitui.rc", true );
	
	
	TQWhatsThis::add( this, i18n(
			"Construct a circuit by dragging components from the Component selector from the left. Create the connections by dragging a wire from the component connectors.<br><br>"
					
			"The simulation is running by default, but can be paused and resumed from the Tools menu.<br><br>"
					
			"To delete a wire, select it with a select box, and hit delete.<br><br>"
					
			"To edit the attributes of a component, select it (making sure that no components of another type are also selected), and edit in the toolbar. More advanced properties can be edited using the item editor on the right.<br><br>"
					
			"Subcircuits can be created by connecting the components with an External Connection, selecting the desired components and clicking on \"Create Subcircuit\" in the right-click menu.")
				   );
	
	m_pViewIface = new CircuitViewIface(this);
	
	m_statusBar->insertItem( "", ViewStatusBar::SimulationState );
	connect( Simulator::self(), TQT_SIGNAL(simulatingStateChanged(bool )), this, TQT_SLOT(slotUpdateRunningStatus(bool )) );
	slotUpdateRunningStatus( Simulator::self()->isSimulating() );
}


CircuitView::~CircuitView()
{
	delete m_pViewIface;
	m_pViewIface = 0l;
}


void CircuitView::slotUpdateRunningStatus( bool isRunning )
{
	m_statusBar->changeItem( isRunning ? i18n("Simulation Running") : i18n("Simulation Paused"), ViewStatusBar::SimulationState );
}


void CircuitView::dragEnterEvent( TQDragEnterEvent * e )
{
	ICNView::dragEnterEvent(e);
	if ( e->isAccepted() )
		return;
	
	e->accept( e->provides("ktechlab/component") || e->provides("ktechlab/subcircuit") );
}

#include "circuitview.moc"

==> ktechlab-trinity-14.1.4.tar.xz: ktechlab-trinity-14.1.4/src/circuitview.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by David Saxton                                    *
 *   david@bluehaze.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "circuitdocument.h"
#include "circuitview.h"
#include "ktechlab.h"
#include "simulator.h"
#include "viewiface.h"

#include <tdelocale.h>
#include <tqwhatsthis.h>

CircuitView::CircuitView( CircuitDocument * circuitDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name )
	: ICNView( circuitDocument, viewContainer, viewAreaId, name ),
	p_circuitDocument(circuitDocument)
{
	TDEActionCollection * ac = actionCollection();
	
	new TDEAction( "Dump linear equations", TQt::CTRL|TQt::Key_D, circuitDocument, TQ_SLOT(displayEquations()), ac, "dump_les" );
	
	//BEGIN Item Control Actions
	TDERadioAction * ra;
	ra = new TDERadioAction( i18n("0 Degrees"), "", 0, circuitDocument, TQ_SLOT(setOrientation0()), ac, "edit_orientation_0" );
	ra->setExclusiveGroup("orientation");
	ra->setChecked(true);
	ra = new TDERadioAction( i18n("90 Degrees"), "", 0, circuitDocument, TQ_SLOT(setOrientation90()), ac, "edit_orientation_90" );
	ra->setExclusiveGroup("orientation");
	ra = new TDERadioAction( i18n("180 Degrees"), "", 0, circuitDocument, TQ_SLOT(setOrientation180()), ac, "edit_orientation_180" );
	ra->setExclusiveGroup("orientation");
	ra =new TDERadioAction( i18n("270 Degrees"), "", 0, circuitDocument, TQ_SLOT(setOrientation270()), ac, "edit_orientation_270" );
	ra->setExclusiveGroup("orientation");
	
	new TDEAction( i18n("Create Subcircuit"), "", 0, circuitDocument, TQ_SLOT(createSubcircuit()), ac, "circuit_create_subcircuit" );
	new TDEAction( i18n("Rotate Clockwise"), "object-rotate-right", "]", circuitDocument, TQ_SLOT(rotateClockwise()), ac, "edit_rotate_cw" );
	new TDEAction( i18n("Rotate Counter-Clockwise"), "object-rotate-left", "[", circuitDocument, TQ_SLOT(rotateCounterClockwise()), ac, "edit_rotate_ccw" );
	new TDEAction( i18n("Flip"), "", 0, circuitDocument, TQ_SLOT(itemFlip()), ac, "edit_flip" );
	//END Item Control Actions
	
	setXMLFile( "ktechlabcircuitui.rc", true );
	
	
	TQWhatsThis::add( this, i18n(
			"Construct a circuit by dragging components from the Component selector from the left. Create the connections by dragging a wire from the component connectors.<br><br>"
					
			"The simulation is running by default, but can be paused and resumed from the Tools menu.<br><br>"
					
			"To delete a wire, select it with a select box, and hit delete.<br><br>"
					
			"To edit the attributes of a component, select it (making sure that no components of another type are also selected), and edit in the toolbar. More advanced properties can be edited using the item editor on the right.<br><br>"
					
			"Subcircuits can be created by connecting the components with an External Connection, selecting the desired components and clicking on \"Create Subcircuit\" in the right-click menu.")
				   );
	
	m_pViewIface = new CircuitViewIface(this);
	
	m_statusBar->insertItem( "", ViewStatusBar::SimulationState );
	connect( Simulator::self(), TQ_SIGNAL(simulatingStateChanged(bool )), this, TQ_SLOT(slotUpdateRunningStatus(bool )) );
	slotUpdateRunningStatus( Simulator::self()->isSimulating() );
}


CircuitView::~CircuitView()
{
	delete m_pViewIface;
	m_pViewIface = 0l;
}


void CircuitView::slotUpdateRunningStatus( bool isRunning )
{
	m_statusBar->changeItem( isRunning ? i18n("Simulation Running") : i18n("Simulation Paused"), ViewStatusBar::SimulationState );
}


void CircuitView::dragEnterEvent( TQDragEnterEvent * e )
{
	ICNView::dragEnterEvent(e);
	if ( e->isAccepted() )
		return;
	
	e->accept( e->provides("ktechlab/component") || e->provides("ktechlab/subcircuit") );
}

#include "circuitview.moc"
